@@ -36,9 +36,9 @@ from odcs.server.errors import NotFound, Forbidden
 import pkg_resources
 
 try:
-    version = pkg_resources.get_distribution('odcs').version
+    version = pkg_resources.get_distribution("odcs").version
 except pkg_resources.DistributionNotFound:
-    version = 'unknown'
+    version = "unknown"
 
 app = Flask(__name__)
 app.wsgi_app = ReverseProxy(app.wsgi_app)
@@ -53,17 +53,15 @@ log = getLogger(__name__)
 login_manager = LoginManager()
 login_manager.init_app(app)
 
-from odcs.server import views # noqa
+from odcs.server import views  # noqa
+
+from odcs.server.auth import init_auth  # noqa
 
-from odcs.server.auth import init_auth # noqa
 init_auth(login_manager, conf.auth_backend)
 
 
 def json_error(status, error, message):
-    response = jsonify(
-        {'status': status,
-         'error': error,
-         'message': message})
+    response = jsonify({"status": status, "error": error, "message": message})
     response.status_code = status
     return response
 
@@ -71,35 +69,35 @@ def json_error(status, error, message):
 @app.errorhandler(NotFound)
 def notfound_error(e):
     """Flask error handler for NotFound exceptions"""
-    return json_error(404, 'Not Found', e.args[0])
+    return json_error(404, "Not Found", e.args[0])
 
 
 @app.errorhandler(Unauthorized)
 def unauthorized_error(e):
     """Flask error handler for Unauthorized exceptions"""
-    return json_error(401, 'Unauthorized', e.description)
+    return json_error(401, "Unauthorized", e.description)
 
 
 @app.errorhandler(Forbidden)
 def forbidden_error(e):
     """Flask error handler for Forbidden exceptions"""
-    return json_error(403, 'Forbidden', e.args[0])
+    return json_error(403, "Forbidden", e.args[0])
 
 
 @app.errorhandler(BadRequest)
 def badrequest_error(e):
     """Flask error handler for RuntimeError exceptions"""
-    return json_error(400, 'Bad Request', e.get_description())
+    return json_error(400, "Bad Request", e.get_description())
 
 
 @app.errorhandler(ValueError)
 def validationerror_error(e):
     """Flask error handler for ValueError exceptions"""
-    return json_error(400, 'Bad Request', str(e))
+    return json_error(400, "Bad Request", str(e))
 
 
 @app.errorhandler(Exception)
 def internal_server_error(e):
     """Flask error handler for RuntimeError exceptions"""
-    log.exception('Internal server error: %s', e)
-    return json_error(500, 'Internal Server Error', str(e))
+    log.exception("Internal server error: %s", e)
+    return json_error(500, "Internal Server Error", str(e))
