@@ -21,6 +21,7 @@
 #
 # Written by Jan Kaluza <jkaluza@redhat.com>
 
+import contextlib
 import ssl
 import os
 import re
@@ -101,7 +102,7 @@ celery_app.conf.update({"task_routes": ("odcs.server.celery_tasks.TaskRouter")})
 
 
 class TaskRouter:
-    """ Custom Celery router """
+    """Custom Celery router"""
 
     def __init__(self):
         self.config = conf.celery_router_config
@@ -123,7 +124,7 @@ class TaskRouter:
         return {"queue": queue}
 
     def __get_queue_for_compose(self, compose_md, task_name):
-        """ Goes through routing rules configured for a task returns a queue on the first match. """
+        """Goes through routing rules configured for a task returns a queue on the first match."""
         rules = {}
         if self.config["routing_rules"].get(task_name):
             rules.update(self.config["routing_rules"][task_name])
@@ -307,6 +308,18 @@ def run_cleanup():
     """
     Runs the cleanup.
     """
-    remove_expired_compose_thread.do_work()
-    composer_thread.fail_lost_generating_composes()
-    reschedule_waiting_composes()
+
+    @contextlib.contextmanager
+    def log_errors(msg):
+        """Log any exception raised from the block and then ignore it."""
+        try:
+            yield
+        except Exception:
+            log.exception(msg)
+
+    with log_errors("Error while removing expired composes"):
+        remove_expired_compose_thread.do_work()
+    with log_errors("Error while marking lost generating composes as failed"):
+        composer_thread.fail_lost_generating_composes()
+    with log_errors("Error while rescheduling waiting composes"):
+        reschedule_waiting_composes()
