@@ -7,16 +7,18 @@ Create Date: 2020-02-05 13:20:59.014127
 """
 
 # revision identifiers, used by Alembic.
-revision = '82172e6a3154'
-down_revision = 'cd0781bbdab1'
+revision = "82172e6a3154"
+down_revision = "cd0781bbdab1"
 
 from alembic import op
 import sqlalchemy as sa
 
 
 def upgrade():
-    op.add_column('composes', sa.Column('pungi_config_dump', sa.String(), nullable=True))
+    op.add_column(
+        "composes", sa.Column("pungi_config_dump", sa.String(), nullable=True)
+    )
 
 
 def downgrade():
-    op.drop_column('composes', 'pungi_config_dump')
+    op.drop_column("composes", "pungi_config_dump")
